==> qtjambi-qt3drender-5.15.8-sources.jar: io/qt/qt3d/render/QSpotLight.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulate a Spot Light object in a Qt 3D scene</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html">Qt3DRender::QSpotLight</a></p>
 */
public class QSpotLight extends io.qt.qt3d.render.QAbstractLight
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSpotLight.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#constantAttenuation-prop">Qt3DRender::QSpotLight::constantAttenuationChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="constantAttenuation")
    public final Signal1<@io.qt.QtPrimitiveType Float> constantAttenuationChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#cutOffAngle-prop">Qt3DRender::QSpotLight::cutOffAngleChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="cutOffAngle")
    public final Signal1<@io.qt.QtPrimitiveType Float> cutOffAngleChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#linearAttenuation-prop">Qt3DRender::QSpotLight::linearAttenuationChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="linearAttenuation")
    public final Signal1<@io.qt.QtPrimitiveType Float> linearAttenuationChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#localDirection-prop">Qt3DRender::QSpotLight::localDirectionChanged(QVector3D)</a></p>
     */
    @io.qt.QtPropertyNotify(name="localDirection")
    public final Signal1<io.qt.gui.QVector3D> localDirectionChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#quadraticAttenuation-prop">Qt3DRender::QSpotLight::quadraticAttenuationChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="quadraticAttenuation")
    public final Signal1<@io.qt.QtPrimitiveType Float> quadraticAttenuationChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QSpotLight(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSpotLight() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#QSpotLight">Qt3DRender::QSpotLight::QSpotLight(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QSpotLight(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSpotLight instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#constantAttenuation-prop">Qt3DRender::QSpotLight::constantAttenuation()const</a></p>
     */
    @io.qt.QtPropertyReader(name="constantAttenuation")
    @io.qt.QtUninvokable
    public final float constantAttenuation(){
        return constantAttenuation_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float constantAttenuation_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#cutOffAngle-prop">Qt3DRender::QSpotLight::cutOffAngle()const</a></p>
     */
    @io.qt.QtPropertyReader(name="cutOffAngle")
    @io.qt.QtUninvokable
    public final float cutOffAngle(){
        return cutOffAngle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float cutOffAngle_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#linearAttenuation-prop">Qt3DRender::QSpotLight::linearAttenuation()const</a></p>
     */
    @io.qt.QtPropertyReader(name="linearAttenuation")
    @io.qt.QtUninvokable
    public final float linearAttenuation(){
        return linearAttenuation_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float linearAttenuation_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#localDirection-prop">Qt3DRender::QSpotLight::localDirection()const</a></p>
     */
    @io.qt.QtPropertyReader(name="localDirection")
    @io.qt.QtUninvokable
    public final io.qt.gui.QVector3D localDirection(){
        return localDirection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QVector3D localDirection_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#quadraticAttenuation-prop">Qt3DRender::QSpotLight::quadraticAttenuation()const</a></p>
     */
    @io.qt.QtPropertyReader(name="quadraticAttenuation")
    @io.qt.QtUninvokable
    public final float quadraticAttenuation(){
        return quadraticAttenuation_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float quadraticAttenuation_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#constantAttenuation-prop">Qt3DRender::QSpotLight::setConstantAttenuation(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="constantAttenuation")
    public final void setConstantAttenuation(float value){
        setConstantAttenuation_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setConstantAttenuation_native_float(long __this__nativeId, float value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#cutOffAngle-prop">Qt3DRender::QSpotLight::setCutOffAngle(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="cutOffAngle")
    public final void setCutOffAngle(float cutOffAngle){
        setCutOffAngle_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), cutOffAngle);
    }
    
    private native void setCutOffAngle_native_float(long __this__nativeId, float cutOffAngle);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#linearAttenuation-prop">Qt3DRender::QSpotLight::setLinearAttenuation(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="linearAttenuation")
    public final void setLinearAttenuation(float value){
        setLinearAttenuation_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setLinearAttenuation_native_float(long __this__nativeId, float value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#localDirection-prop">Qt3DRender::QSpotLight::setLocalDirection(QVector3D)</a></p>
     */
    @io.qt.QtPropertyWriter(name="localDirection")
    public final void setLocalDirection(io.qt.gui.QVector3D localDirection){
        setLocalDirection_native_cref_QVector3D(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(localDirection));
    }
    
    private native void setLocalDirection_native_cref_QVector3D(long __this__nativeId, long localDirection);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#quadraticAttenuation-prop">Qt3DRender::QSpotLight::setQuadraticAttenuation(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="quadraticAttenuation")
    public final void setQuadraticAttenuation(float value){
        setQuadraticAttenuation_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setQuadraticAttenuation_native_float(long __this__nativeId, float value);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSpotLight(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSpotLight(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSpotLight instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QSpotLight.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulate a Spot Light object in a Qt 3D scene</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html">Qt3DRender::QSpotLight</a></p>
 */
public class QSpotLight extends io.qt.qt3d.render.QAbstractLight
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSpotLight.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#constantAttenuation-prop">Qt3DRender::QSpotLight::constantAttenuationChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="constantAttenuation")
    public final Signal1<@io.qt.QtPrimitiveType Float> constantAttenuationChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#cutOffAngle-prop">Qt3DRender::QSpotLight::cutOffAngleChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="cutOffAngle")
    public final Signal1<@io.qt.QtPrimitiveType Float> cutOffAngleChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#linearAttenuation-prop">Qt3DRender::QSpotLight::linearAttenuationChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="linearAttenuation")
    public final Signal1<@io.qt.QtPrimitiveType Float> linearAttenuationChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#localDirection-prop">Qt3DRender::QSpotLight::localDirectionChanged(QVector3D)</a></p>
     */
    @io.qt.QtPropertyNotify(name="localDirection")
    public final Signal1<io.qt.gui.QVector3D> localDirectionChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#quadraticAttenuation-prop">Qt3DRender::QSpotLight::quadraticAttenuationChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="quadraticAttenuation")
    public final Signal1<@io.qt.QtPrimitiveType Float> quadraticAttenuationChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QSpotLight(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSpotLight() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#QSpotLight">Qt3DRender::QSpotLight::QSpotLight(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QSpotLight(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSpotLight instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#constantAttenuation-prop">Qt3DRender::QSpotLight::constantAttenuation()const</a></p>
     */
    @io.qt.QtPropertyReader(name="constantAttenuation")
    @io.qt.QtUninvokable
    public final float constantAttenuation(){
        return constantAttenuation_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float constantAttenuation_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#cutOffAngle-prop">Qt3DRender::QSpotLight::cutOffAngle()const</a></p>
     */
    @io.qt.QtPropertyReader(name="cutOffAngle")
    @io.qt.QtUninvokable
    public final float cutOffAngle(){
        return cutOffAngle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float cutOffAngle_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#linearAttenuation-prop">Qt3DRender::QSpotLight::linearAttenuation()const</a></p>
     */
    @io.qt.QtPropertyReader(name="linearAttenuation")
    @io.qt.QtUninvokable
    public final float linearAttenuation(){
        return linearAttenuation_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float linearAttenuation_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#localDirection-prop">Qt3DRender::QSpotLight::localDirection()const</a></p>
     */
    @io.qt.QtPropertyReader(name="localDirection")
    @io.qt.QtUninvokable
    public final io.qt.gui.QVector3D localDirection(){
        return localDirection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QVector3D localDirection_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#quadraticAttenuation-prop">Qt3DRender::QSpotLight::quadraticAttenuation()const</a></p>
     */
    @io.qt.QtPropertyReader(name="quadraticAttenuation")
    @io.qt.QtUninvokable
    public final float quadraticAttenuation(){
        return quadraticAttenuation_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float quadraticAttenuation_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#constantAttenuation-prop">Qt3DRender::QSpotLight::setConstantAttenuation(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="constantAttenuation")
    public final void setConstantAttenuation(float value){
        setConstantAttenuation_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setConstantAttenuation_native_float(long __this__nativeId, float value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#cutOffAngle-prop">Qt3DRender::QSpotLight::setCutOffAngle(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="cutOffAngle")
    public final void setCutOffAngle(float cutOffAngle){
        setCutOffAngle_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), cutOffAngle);
    }
    
    private native void setCutOffAngle_native_float(long __this__nativeId, float cutOffAngle);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#linearAttenuation-prop">Qt3DRender::QSpotLight::setLinearAttenuation(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="linearAttenuation")
    public final void setLinearAttenuation(float value){
        setLinearAttenuation_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setLinearAttenuation_native_float(long __this__nativeId, float value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#localDirection-prop">Qt3DRender::QSpotLight::setLocalDirection(QVector3D)</a></p>
     */
    @io.qt.QtPropertyWriter(name="localDirection")
    public final void setLocalDirection(io.qt.gui.QVector3D localDirection){
        setLocalDirection_native_cref_QVector3D(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(localDirection));
    }
    
    private native void setLocalDirection_native_cref_QVector3D(long __this__nativeId, long localDirection);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qspotlight.html#quadraticAttenuation-prop">Qt3DRender::QSpotLight::setQuadraticAttenuation(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="quadraticAttenuation")
    public final void setQuadraticAttenuation(float value){
        setQuadraticAttenuation_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setQuadraticAttenuation_native_float(long __this__nativeId, float value);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSpotLight(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSpotLight(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSpotLight instance, QDeclarativeConstructor constructor);
    
}
